==> plantuml-libs-9.0.0.tgz: package/distribution/aws-q2-2022/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtps.md <==
# AwsTransferFamilyAwsFtps


```text
aws-q2-2022/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtps
```

```text
include('aws-q2-2022/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtps')
```



| Illustration | AwsTransferFamilyAwsFtps | AwsTransferFamilyAwsFtpsCard | AwsTransferFamilyAwsFtpsGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q2-2022/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtps.png) | ![illustration for AwsTransferFamilyAwsFtps](../../../aws-q2-2022/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtps.Local.png) | ![illustration for AwsTransferFamilyAwsFtpsCard](../../../aws-q2-2022/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtpsCard.Local.png) | ![illustration for AwsTransferFamilyAwsFtpsGroup](../../../aws-q2-2022/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtpsGroup.Local.png) |




## AwsTransferFamilyAwsFtps

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsFtps
include('aws-q2-2022/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtps')

' renders the element
AwsTransferFamilyAwsFtps('AwsTransferFamilyAwsFtps', 'Aws Transfer Family Aws Ftps', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsFtps
include('aws-q2-2022/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtps')

' renders the element
AwsTransferFamilyAwsFtps('AwsTransferFamilyAwsFtps', 'Aws Transfer Family Aws Ftps', 'an optional tech label')
@enduml
```

## AwsTransferFamilyAwsFtpsCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsFtpsCard
include('aws-q2-2022/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtps')

' renders the element
AwsTransferFamilyAwsFtpsCard('AwsTransferFamilyAwsFtpsCard', 'Aws Transfer Family Aws Ftps Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsFtpsCard
include('aws-q2-2022/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtps')

' renders the element
AwsTransferFamilyAwsFtpsCard('AwsTransferFamilyAwsFtpsCard', 'Aws Transfer Family Aws Ftps Card', 'an optional description')
@enduml
```

## AwsTransferFamilyAwsFtpsGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsFtpsGroup
include('aws-q2-2022/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtps')

' renders the element
AwsTransferFamilyAwsFtpsGroup('AwsTransferFamilyAwsFtpsGroup', 'Aws Transfer Family Aws Ftps Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsFtpsGroup
include('aws-q2-2022/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtps')

' renders the element
AwsTransferFamilyAwsFtpsGroup('AwsTransferFamilyAwsFtpsGroup', 'Aws Transfer Family Aws Ftps Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/aws-q2-2022/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtps.md <==
# AwsTransferFamilyAwsFtps


```text
aws-q2-2022/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtps
```

```text
include('aws-q2-2022/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtps')
```



| Illustration | AwsTransferFamilyAwsFtps | AwsTransferFamilyAwsFtpsCard | AwsTransferFamilyAwsFtpsGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q2-2022/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtps.png) | ![illustration for AwsTransferFamilyAwsFtps](../../../aws-q2-2022/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtps.Local.png) | ![illustration for AwsTransferFamilyAwsFtpsCard](../../../aws-q2-2022/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtpsCard.Local.png) | ![illustration for AwsTransferFamilyAwsFtpsGroup](../../../aws-q2-2022/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtpsGroup.Local.png) |




## AwsTransferFamilyAwsFtps

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsFtps
include('aws-q2-2022/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtps')

' renders the element
AwsTransferFamilyAwsFtps('AwsTransferFamilyAwsFtps', 'Aws Transfer Family Aws Ftps', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsFtps
include('aws-q2-2022/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtps')

' renders the element
AwsTransferFamilyAwsFtps('AwsTransferFamilyAwsFtps', 'Aws Transfer Family Aws Ftps', 'an optional tech label', 'an optional description')
@enduml
```

## AwsTransferFamilyAwsFtpsCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsFtpsCard
include('aws-q2-2022/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtps')

' renders the element
AwsTransferFamilyAwsFtpsCard('AwsTransferFamilyAwsFtpsCard', 'Aws Transfer Family Aws Ftps Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsFtpsCard
include('aws-q2-2022/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtps')

' renders the element
AwsTransferFamilyAwsFtpsCard('AwsTransferFamilyAwsFtpsCard', 'Aws Transfer Family Aws Ftps Card', 'an optional description')
@enduml
```

## AwsTransferFamilyAwsFtpsGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsFtpsGroup
include('aws-q2-2022/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtps')

' renders the element
AwsTransferFamilyAwsFtpsGroup('AwsTransferFamilyAwsFtpsGroup', 'Aws Transfer Family Aws Ftps Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsFtpsGroup
include('aws-q2-2022/Resource/MigrationAndTransfer/AwsTransferFamilyAwsFtps')

' renders the element
AwsTransferFamilyAwsFtpsGroup('AwsTransferFamilyAwsFtpsGroup', 'Aws Transfer Family Aws Ftps Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
